from edc_constants.constants import NO, NOT_APPLICABLE, YES

BMI_FBG_OGTT_INCOMPLETE = "BMI/FBG/OGTT incomplete"
BMI_FBG_OGTT = "BMI/FBG/OGTT"
EGFR_NOT_CALCULATED = "eGFR not calculated"
EGFR_LT_45 = "eGFR<45"
FBG_OGTT_INCOMPLETE = "FBG/OGTT incomplete"
FBG_OGTT = "FBG/OGTT"
PART_ONE = "p1"
PART_TWO = "p2"
PART_THREE = "p3"

PREG_YES_NO_NA = (
    (YES, "Yes"),
    (NO, "No"),
    (NOT_APPLICABLE, "Not Applicable: e.g. mentruating, post menopausal, not female"),
)

CONVERSION_FACTOR = 18.018018
SEVERE_HTN = "Severe HTN"
PENDING_REPEAT = "pending_p3_repeat"
PRE_DM = "pre_dm"
HI_OGTT = "hi_ogtt"
NORMAL_FBG_OGTT = "normal_fbg_ogtt"
HI_FBG = "hi_fbg"
